==> alliance-5.0-20020701.tar.gz: alliance-5.0/boom/src/boom_bdd.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail support : mailto:alliance-support@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                     BOOM                           |
|                                                             |
| File    :                   boom_bdd.h                       |
|                                                             |
| Author  :                 Jacomme Ludovic                   |
|                                                             |
| Date    :                   06.06.00                        |
|                                                             |
\------------------------------------------------------------*/

# ifndef BOOM_BDD_H
# define BOOM_BDD_H

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/

# define BOOM_BDD_NODE_BIG_SIZE           8
# define BOOM_BDD_EXPLOSION_LIMIT    200000
# define BOOM_BDD_SWAP_LIMIT          10000

/*------------------------------------------------------------\
|                                                             |
|                            Macro                            |
|                                                             |
\------------------------------------------------------------*/

/*
# define BoomSetBddMarkAbl( E, N ) \
                                  \
  do { ABL_CDR( ABL_CAR( E ) ) = (chain_list *)(N); \
       if ( (N)->MARK == 0 ) (N)->MARK = 1; \
       else                  (N)->MARK = 2; \
       incbddrefext( (N) ); \
     } while (0)
*/

# define BoomSetBddMarkAbl( E, N ) \
                                  \
  do { ABL_CDR( ABL_CAR( E ) ) = (chain_list *)(N); \
       if ( (N)->MARK == 0 ) incbddrefext( (N) ); \
       (N)->MARK++; \
     } while (0)

# define BoomGetBddMarkAbl( E ) \
                               \
  ( (bddnode *)( ABL_CDR( ABL_CAR( E ) ) ) )

/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Varibddes                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/

  extern void  BoomBehAbl2BddNode();
  extern void  BoomBehMakeBddNode();
  extern void  BoomBehResetBddNode();
  extern void  BoomBehUnmarkBddNode();
  extern void  BoomBehScanBdd();
  extern void  BoomBehMapBdd();
  extern long  BoomBehGetNumberBigBddNode();

  extern chain_list *BoomUnmarkBddNode();
  extern chain_list *BoomBehGetBddOrder();
  extern void        BoomBehRandomBddOrder();
  extern void        BoomBehRebuildBddNode();

# endif

==> alliance_5.0-20110203.orig.tar.gz: alliance-5.0/boom/src/boom_bdd.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail         : mailto:alliance-users@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                     BOOM                           |
|                                                             |
| File    :                   boom_bdd.h                       |
|                                                             |
| Author  :                 Jacomme Ludovic                   |
|                                                             |
| Date    :                   06.06.00                        |
|                                                             |
\------------------------------------------------------------*/

# ifndef BOOM_BDD_H
# define BOOM_BDD_H

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/

# define BOOM_BDD_NODE_BIG_SIZE           8
# define BOOM_BDD_EXPLOSION_LIMIT    200000
# define BOOM_BDD_SWAP_LIMIT          10000

/*------------------------------------------------------------\
|                                                             |
|                            Macro                            |
|                                                             |
\------------------------------------------------------------*/

/*
# define BoomSetBddMarkAbl( E, N ) \
                                  \
  do { ABL_CDR( ABL_CAR( E ) ) = (chain_list *)(N); \
       if ( (N)->MARK == 0 ) (N)->MARK = 1; \
       else                  (N)->MARK = 2; \
       incbddrefext( (N) ); \
     } while (0)
*/

# define BoomSetBddMarkAbl( E, N ) \
                                  \
  do { ABL_CDR( ABL_CAR( E ) ) = (chain_list *)(N); \
       if ( (N)->MARK == 0 ) incbddrefext( (N) ); \
       (N)->MARK++; \
     } while (0)

# define BoomGetBddMarkAbl( E ) \
                               \
  ( (bddnode *)( ABL_CDR( ABL_CAR( E ) ) ) )

/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Varibddes                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/

  extern void  BoomBehAbl2BddNode();
  extern void  BoomBehMakeBddNode();
  extern void  BoomBehResetBddNode();
  extern void  BoomBehUnmarkBddNode();
  extern void  BoomBehScanBdd();
  extern void  BoomBehMapBdd();
  extern long  BoomBehGetNumberBigBddNode();

  extern chain_list *BoomUnmarkBddNode();
  extern chain_list *BoomBehGetBddOrder();
  extern void        BoomBehRandomBddOrder();
  extern void        BoomBehRebuildBddNode();

# endif
